#!/usr/bin/env python
# -*- coding: utf-8 -*-
from builtins import str
from pynamodb.exceptions import GetError

from db_paribhasha import credentials as creds
from db_paribhasha.dynamo import dynamo_constants as db_cnts
from db_paribhasha.dynamo import dynamo_helpers as db_hlpr
from db_paribhasha.dynamo.userrequest import UserRequestDynamoDB
from db_paribhasha.error_handler import DynamoDBError


def create_table():
    """
    Creates PreLoginDynamoDB table if table doesn't exist
    """
    if UserRequestDynamoDB.exists():
        raise DynamoDBError(db_cnts.TABLE_EXISTS.format(creds.DYNAMO_USER_REQUEST_TABLE))
    UserRequestDynamoDB.create_table(
        read_capacity_units=creds.DYNAMO_PRELOGIN_READ_UNITS,
        write_capacity_units=creds.DYNAMO_PRELOGIN_WRITE_UNITS)


def get_user_request_data(email):
    """
    Returns the data based on email

    Parameters
    ----------
    email : str
        email of the user

    Returns
    -------
    data: dict
        Metadata fetched on the basis of email
    """
    try:
        data = UserRequestDynamoDB.get(email)
    except GetError as err:
        raise DynamoDBError(str(err))
    return data.to_dict()


def save_user_request_data(email, 
                           query_type,
                           other_data,
                           org=None, 
                           designation=None,
                           demo_time=None):
    """
    Saves the data based on page URL

    Parameters
    ----------
    email : str
        email of the User
    org: str
        organisation name
    designation: str
        designation of the user
    demo_time: str
        demo_time
    other_data: dict
        Other data includes data.
        Ex- Questionnarire data, query_msg, event_status( cancelled, Created)
    query_type: str
        Type of User request (Ex- Demo, Query, Subscribe Request Types)

    Returns
    -------
    bool: True if object gets saved in dynamodb
    """
    create_metadata = UserRequestDynamoDB(email=email,
                                          query_type=query_type,
                                          org=org,
                                          other_data=other_data,
                                          designation=designation,
                                          demo_time=demo_time)
    db_hlpr.save_dynamo_object(create_metadata)
    return True
