from db_paribhasha import db_constants
from db_paribhasha.base_models.sql_base_model import Base

from sqlalchemy import Column, Integer, String, DateTime, ForeignKey, JSON, Boolean
from sqlalchemy.sql import func, expression


class Iteration(Base):
    """
    Model corresponding to Iteration relation.

    Each iteration will be captured in this relation. Each iteration will be
    related to an ecs_task that the user has initiated. Ex: Validating input
    files, NA correction, etc.
    :TODO: Pass Boolean variable to is_active key
    """
    __tablename__ = db_constants.ITERATION_TABLE_NAME

    id = Column(Integer, primary_key=True, nullable=False,
                   autoincrement=True)
    created_time = Column(DateTime, server_default=func.now(),
                             nullable=False)
    modified_time = Column(DateTime, server_default=func.now(),
                              onupdate=func.now(), nullable=False)
    workflow_request = Column(Integer, ForeignKey(
        db_constants.WORKFLOW_REQUEST_TABLE_NAME + ".id", ondelete="CASCADE"),
        nullable=True)
    type = Column(String(10), nullable=True)
    state = Column(String)
    heartbeat = Column(Integer)
    download_filename = Column(JSON)
    parameter_filename = Column(JSON)
    iteration_info = Column(JSON)
    algorithm = Column(Integer, ForeignKey(
        db_constants.ALGORITHM_TABLE_NAME + ".id", ondelete="CASCADE"), nullable=True)
    is_active = Column(Boolean,default='t', nullable=False, server_default=expression.true())

    def as_dict(self):
        """
        Returns the model as dict.
        """
        return_object = {
            'id': self.id,
            'created_time': self.created_time,
            'modified_time': self.modified_time,
            'state': self.state,
            'type': self.type,
            'heartbeat': self.heartbeat,
            'download_filename': self.download_filename,
            'parameter_filename': self.parameter_filename,
            'algorithm': self.algorithm,
	    'iteration_info':self.iteration_info,
        'is_active': self.is_active
        }

        if self.type == 'workflow':
            return_object['workflow_request'] = self.workflow_request

        return return_object

